@@ -30,6 +30,8 @@ class TextGenerationCallback(TrainerCallback):
         self.header_fmt = '{sep}GLOBAL STEP {global_step}{sep}'
 
     def on_evaluate(self, args, state, control, **kwargs):
+        if not state.is_world_process_zero:
+            return
         with open(self.out_path, 'a') as f:
             f.write(self.header_fmt.format(sep=self.sep,
                                            global_step=state.global_step))
